import { LanguageSupport, LezerLanguage } from "@codemirror/language";
type Position = {
    from: number;
    to: number;
};
type KarolProgram = {
    start: TreeNode[];
    subroutines: Record<string, Subroutine>;
    conditions: Record<string, Condition>;
};
type KarolError = {
    kind: "error";
    msg: string;
    pos: Position;
};
type CompilationResult = {
    kind: "success";
    result: KarolProgram;
} | KarolError;
type ExecutionResult = {
    kind: "success";
} | KarolError;
type Statement = {
    kind: "statement";
    identifier: string;
    pos: Position;
};
type StatementWithParam = {
    kind: "statementWithParam";
    identifier: string;
    param: string;
    pos: Position;
};
type Subroutine = {
    kind: "subroutine";
    identifier: string;
    body: TreeNode[];
    pos: Position;
};
type Condition = {
    kind: "condition";
    identifier: string;
    body: TreeNode[];
    pos: Position;
};
type If = {
    kind: "if";
    inverted: boolean;
    condition: TreeNode;
    body: TreeNode[];
    pos: Position;
};
type IfElse = {
    kind: "ifElse";
    inverted: boolean;
    condition: TreeNode;
    body: TreeNode[];
    elseBody: TreeNode[];
    pos: Position;
};
type WhileForever = {
    kind: "whileForever";
    body: TreeNode[];
    pos: Position;
};
type WhileTimes = {
    kind: "whileTimes";
    times: number;
    body: TreeNode[];
    pos: Position;
};
type While = {
    kind: "while";
    inverted: boolean;
    condition: TreeNode;
    body: TreeNode[];
    pos: Position;
};
type WhileEnd = {
    kind: "whileEnd";
    inverted: boolean;
    condition: TreeNode;
    body: TreeNode[];
    pos: Position;
};
type TreeNode = Statement | StatementWithParam | Subroutine | Condition | If | IfElse | WhileForever | WhileTimes | While | WhileEnd;
declare const karolLanguage: LezerLanguage;
declare function karol(): LanguageSupport;
declare function parse(str: string): import("lezer-tree").Tree;
declare function compile(str: string): CompilationResult;
declare class KarolInterpreter {
    prog: KarolProgram;
    cs: string[];
    bs: boolean[];
    is: number[];
    p: number[];
    constructor(prog: KarolProgram);
    getTop(arr: any[]): any;
    next(): ExecutionResult;
}
export { karolLanguage, karol, parse, compile, KarolInterpreter };
